@@ -69,12 +69,22 @@ ONE_TO_THREE = {'A':'ALA',
 DEFAULT_SIDECHAIN_VECTOR_ATOMS = {'ALA': 'CB', 
                                   'CYS': 'SG',
                                   'ASP': 'CG',
+                                  'ASH': 'CG',
                                   'GLU': 'CD',
+                                  'GLH': 'CD',
                                   'PHE': 'CZ',
                                   'GLY': 'ERROR',
-                                  'HIS': 'NE2', 
+                                  'HIS': 'NE2',
+                                  'HID': 'NE2',
+                                  'HIE': 'NE2',
+                                  'HIP': 'NE2', 
                                   'ILE': 'CD1',
                                   'LYS': 'NZ',
+                                  'LYD': 'NZ',
+                                  'KAC': 'NZ',
+                                  'KM1': 'NZ',
+                                  'KM2': 'NZ',
+                                  'KM3': 'NZ',
                                   'LEU': 'CG',
                                   'MET': 'CE',
                                   'ASN': 'CG',
@@ -82,12 +92,15 @@ DEFAULT_SIDECHAIN_VECTOR_ATOMS = {'ALA': 'CB',
                                   'GLN': 'CD',
                                   'ARG': 'CZ',
                                   'SER': 'OG',
+                                  'SEP': 'OG',
                                   'THR': 'CB',
+                                  'TPO': 'CB',
                                   'VAL': 'CB',
                                   'TRP': 'CG',
                                   'TYR': 'CZ',
+                                  'PTR': 'CZ',
                                   'ACE': 'ERROR',
                                   'NME': 'ERROR'}
 
-# list of valid residue names as supported by CAMPARI
-ALL_VALID_RESIDUE_NAMES = ['ALA','CYS','ASP','ASH','GLU','GLU','PHE','GLY','HIE','HIS','HID','HIP','ILE','LEU', 'LYS','LYD','MET','ASN','PRO','GLN','ARG','SER','THR','VAL','TRP','TYR','AIB', 'ABA','NVA','NLE', 'ORN', 'DAB','PTR','TPO','SEP', 'KAC', 'KM1', 'KM2' 'KM3', 'ACE','NME', 'FOR', 'NH2']
+# list of valid residue names as supported by SOURSOP. These are the resnames compared againt when assessing for if a molecule is a protein or not. 
+ALL_VALID_RESIDUE_NAMES = ['ALA','CYS','ASP','ASH','GLU','GLH','PHE','GLY','HIE','HIS','HID','HIP','ILE','LEU', 'LYS','LYD','MET','ASN','PRO','GLN','ARG','SER','THR','VAL','TRP','TYR','AIB', 'ABA','NVA','NLE', 'ORN', 'DAB','PTR','TPO','SEP', 'KAC', 'KM1', 'KM2' 'KM3', 'ACE','NME', 'FOR', 'NH2']
